@@ -4,9 +4,10 @@ Additional protocols for ScreenPy Selenium.
 
 from screenpy import Actor
 from selenium.webdriver.common.action_chains import ActionChains
-from typing_extensions import Protocol
+from typing_extensions import Protocol, runtime_checkable
 
 
+@runtime_checkable
 class Chainable(Protocol):
     """Actions that can be added to a chain are Chainable."""
 
@@ -18,4 +19,3 @@ class Chainable(Protocol):
             the_actor: the Actor who will be performing the Action chain.
             the_chain: the |ActionChains| instance that is being built.
         """
-        ...
